@@ -1,5 +1,5 @@
 /* grid.h -- three-dimensional grid of points.  -*- C++ -*-
-   Copyright (C) 2011-2017 Gerardo Ballabio
+   Copyright (C) 2011-2020 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -35,6 +35,11 @@ inline coords make_coords(int x = 0, int y = 0, int z = 0)
   return c;
 }
 
+inline coords operator-(const coords &c)
+{
+  return make_coords(-c.x, -c.y, -c.z);
+}
+
 inline coords operator+(const coords &c1, const coords &c2)
 {
   return make_coords(c1.x + c2.x, c1.y + c2.y, c1.z + c2.z);
@@ -148,7 +153,7 @@ template <class T> bool operator==(const grid<T> &g1, const grid<T> &g2)
     return false;
 
   // check contents
-  for (int i=0; i<static_cast<int>(g1.mask.size()); ++i)
+  for (unsigned i=0; i<g1.mask.size(); ++i)
     if (g1.mask[i] != g2.mask[i])
       return false;
 
