@@ -1,5 +1,5 @@
 /* group.cc -- spatial groups for falling block game.  -*- C++ -*-
-   Copyright (C) 2011-2013 Gerardo Ballabio
+   Copyright (C) 2011-2020 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,34 +19,6 @@
 #include "grid.h"
 #include "group.h"
 
-std::vector<block> random_blocks(const std::vector<block> &v, int n)
-{
-  if (n >= static_cast<int>(v.size()))
-    return v;
-
-  // choose n elements between 0 and v.size() - 1
-  std::vector<int> indexes;
-  for (int i=0; i<n; ++i)
-    {
-      int index = rand() % (v.size() - i), pos;
-      for (pos=0; pos<static_cast<int>(indexes.size()); ++pos)
-	{
-	  if (index >= indexes[pos])
-	    ++index;
-	  else
-	    break;
-	}
-      indexes.insert(indexes.begin() + pos, index); // keep sorted
-    }
-
-  // copy selected elements
-  std::vector<block> r;
-  for (std::vector<int>::const_iterator i=indexes.begin();
-       i!=indexes.end(); ++i)
-    r.push_back(v[*i]);
-  return r;
-}
-
 grid<bool> group::augmentation_set(const grid<bool> &g) const
 {
   grid<bool> s;
@@ -125,8 +97,8 @@ block group::make_block(const grid<bool> &g) const
   block b;
 
   // find symmetry subgroup for this block
-  std::vector<int> subgroup;
-  for (int i=0; i<size(); ++i)
+  std::vector<unsigned> subgroup;
+  for (unsigned i=0; i<size(); ++i)
     {
       grid<bool> t = center(transform(g, i));
       bool dup = false;
@@ -147,11 +119,11 @@ block group::make_block(const grid<bool> &g) const
     }
 
   // remap rotate and reflect onto subgroup
-  for (std::vector<int>::const_iterator i=subgroup.begin();
+  for (std::vector<unsigned>::const_iterator i=subgroup.begin();
        i!=subgroup.end(); ++i)
-    if (*i == static_cast<int>(b.reflect.size()))
+    if (*i == b.reflect.size())
       {
-	for (int j=0; j<rotations(); ++j)
+	for (unsigned j=0; j<rotations(); ++j)
 	  b.rotate.push_back(subgroup[rotate(i - subgroup.begin(), j)]);
 	b.reflect.push_back(subgroup[reflect(i - subgroup.begin())]);
       }
@@ -159,58 +131,48 @@ block group::make_block(const grid<bool> &g) const
   return b;
 }
 
-std::vector<block>
-group::augment_blocks(const std::vector<block> &v,
-		      int x0, int z0, int cols, int layers) const
+block group::block_zero() const
 {
-  if (v.size() == 0)
-    {
-      block b;
-      b.shape.push_back(grid<bool>());
-      b.blocker.push_back(grid<bool>());
-      for (int i=0; i<rotations(); ++i)
-	b.rotate.push_back(0);
-      b.reflect.push_back(0);
-      return std::vector<block>(1, b);
-    }
-  // else
+  block b;
+  b.shape.push_back(grid<bool>());
+  b.blocker.push_back(grid<bool>());
+  for (unsigned i=0; i<rotations(); ++i)
+    b.rotate.push_back(0);
+  b.reflect.push_back(0);
+  return b;
+}
 
-  std::vector<block> u;
-  for (std::vector<block>::const_iterator i=v.begin(); i!=v.end(); ++i)
+void group::augment_block(const block &b, std::vector<block> &v,
+			  int x0, int z0, int cols, int layers) const
+{
+  std::vector<grid<bool> > a = augment_grid(b.shape.front());
+  for (std::vector<grid<bool> >::const_iterator i=a.begin();
+       i!=a.end(); ++i)
     {
-      std::vector<grid<bool> > a = augment_grid(i->shape.front());
-      for (std::vector<grid<bool> >::const_iterator j=a.begin();
-	   j!=a.end(); ++j)
-	{
-	  bool dup = false;
-	  for (std::vector<block>::const_iterator k=u.begin();
-	       k!=u.end(); ++k)
-	    for (std::vector<grid<bool> >::const_iterator l=k->shape.begin();
-		 l!=k->shape.end(); ++l)
-	      if (*j == *l)
-		{
-		  dup = true;
-		  break;
-		}
-	  if (!dup)
+      bool dup = false;
+      for (std::vector<block>::const_iterator j=v.begin();
+	   j!=v.end(); ++j)
+	for (std::vector<grid<bool> >::const_iterator k=j->shape.begin();
+	     k!=j->shape.end(); ++k)
+	  if (*i == *k)
 	    {
-	      block b = make_block(*j);
-	      bool fits = true;
-	      if (cols > 1)
-		{
-		  // check whether block fits within bounds
-		  for (std::vector<grid<bool> >::const_iterator
-			 k=b.shape.begin(); k!=b.shape.end(); ++k)
-		    if (k->get_x0() < x0 ||
-			k->get_x0() + k->get_cols() > x0 + cols ||
-			k->get_z0() < z0 ||
-			k->get_z0() + k->get_layers() > z0 + layers)
-		      fits = false;
-		}
-	      if (fits)
-		u.push_back(b);
+	      dup = true;
+	      break;
 	    }
+      if (!dup)
+	{
+	  block b = make_block(*i);
+	  bool fits = true;
+	  if (cols > 1)
+	    {
+	      // check whether block fits within bounds
+	      for (std::vector<grid<bool> >::const_iterator l=b.shape.begin();
+		   l!=b.shape.end(); ++l)
+		if (l->get_cols() > cols || l->get_layers() > layers)
+		  fits = false;
+	    }
+	  if (fits)
+	    v.push_back(b);
 	}
     }
-  return u;
 }
