@@ -1,5 +1,5 @@
 /* main.cc -- main window for falling blocks game.  -*- C++ -*-
-   Copyright (C) 2011-2018 Gerardo Ballabio
+   Copyright (C) 2011-2020 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -98,7 +98,7 @@ bool MainWindow::on_key_press_event(GdkEventKey *event)
 	  if (refresh)
 	    board_area.set_block(board.get_block(),
 				 land ? board.get_shadow() : grid<bool>(),
-				 board.get_iblock());
+				 board.get_index());
 	}
     }
 
@@ -176,10 +176,10 @@ void MainWindow::on_menu_new()
   drop = pause = false;
   board.start_game(g, width, depth, mode1, mode2, speed, bmin, bmax, empty);
   board_area.start_game(g, board.get_cells(), board.get_block(),
-			board.get_iblock());
+			board.get_index());
   next_area.set_group(g);
   if (next)
-    next_area.set_block(board.get_next_block(), board.get_nblock());
+    next_area.set_block(board.get_next_block(), board.get_next_index());
   else
     next_area.set_block(grid<bool>(), 0);
 
@@ -242,6 +242,12 @@ void MainWindow::on_menu_scores()
   scores.show();
 }
 
+void MainWindow::on_menu_quit()
+{
+  on_menu_stop();
+  hide();
+}
+
 void MainWindow::on_menu_help()
 {
 #if GTKMM_MINOR_VERSION >= 22
@@ -272,11 +278,11 @@ void MainWindow::on_menu_about()
   dialog.set_logo(Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB, true, 8, 1, 1));
 
   dialog.set_program_name("Galois");
-  dialog.set_version("0.6");
+  dialog.set_version("0.7");
   dialog.set_comments("A falling blocks game with blocks of various shapes"
 		      " and sizes");
   dialog.set_website("http://www.nongnu.org/galois/");
-  dialog.set_copyright("Copyright © 2011-2018 Gerardo Ballabio");
+  dialog.set_copyright("Copyright © 2011-2020 Gerardo Ballabio");
   dialog.set_license
     ("Galois is free software; you can redistribute it and/or modify\n"
      "it under the terms of the GNU General Public License as published by\n"
@@ -315,7 +321,7 @@ bool MainWindow::on_timeout_down()
   else
     board_area.set_block(board.get_block(),
 			 land ? board.get_shadow() : grid<bool>(),
-			 board.get_iblock());
+			 board.get_index());
 
   return true;
 }
@@ -336,7 +342,7 @@ bool MainWindow::on_timeout_drop()
   else
     board_area.set_block(board.get_block(),
 			 land ? board.get_shadow() : grid<bool>(),
-			 board.get_iblock());
+			 board.get_index());
 
   return true;
 }
@@ -371,9 +377,9 @@ bool MainWindow::on_timeout_lines()
   // new blocks
   board_area.set_block(board.get_block(),
 		       land ? board.get_shadow() : grid<bool>(),
-		       board.get_iblock());
+		       board.get_index());
   if (next)
-    next_area.set_block(board.get_next_block(), board.get_nblock());
+    next_area.set_block(board.get_next_block(), board.get_next_index());
 
   // check for end of game
   if (!board.is_game())
@@ -420,9 +426,9 @@ void MainWindow::on_game_next()
       board.next_block();
       board_area.set_block(board.get_block(),
 			   land ? board.get_shadow() : grid<bool>(),
-			   board.get_iblock());
+			   board.get_index());
       if (next)
-	next_area.set_block(board.get_next_block(), board.get_nblock());
+	next_area.set_block(board.get_next_block(), board.get_next_index());
 
       // check for end of game
       if (!board.is_game())
