@@ -59,7 +59,7 @@ protected:
   virtual void on_menu_stop();
   virtual void on_menu_prefs();
   virtual void on_menu_scores();
-  virtual void on_menu_quit() { hide(); }
+  virtual void on_menu_quit();
   virtual void on_menu_help();
   virtual void on_menu_about();
   virtual void on_response_prefs(int response_id);
