@@ -378,11 +378,8 @@ bool PrefsDialog::load()
   try
     {
       // open file
-      Glib::ustring file =
-	// Debian 6.0 hasn't the three-arguments version
-	// keep supporting it for now
-	Glib::build_filename(Glib::build_filename(Glib::get_user_config_dir(),
-						  "galois"), "galois.conf");
+      Glib::ustring file = Glib::build_filename(Glib::get_user_config_dir(),
+						"galois", "galois.conf");
       xmlpp::TextReader *reader = new xmlpp::TextReader(file);
 
       reader->read();
@@ -507,6 +504,7 @@ bool PrefsDialog::load()
 	      else if (name == "width3")
 		{
 		  width3 = std::atoi(reader->get_value().c_str());
+		  depth_spin.get_adjustment()->set_upper(width3);
 		  if (get_geometry_3d())
 		    width_spin.set_value(width3);
 		}
