@@ -1,5 +1,5 @@
 /* scores.cc -- preferences dialog for falling blocks game.  -*- C++ -*-
-   Copyright (C) 2012-2015 Gerardo Ballabio
+   Copyright (C) 2012-2017 Gerardo Ballabio
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -192,6 +192,12 @@ void ScoresDialog::on_imax_spin_signal_value_changed()
 ScoresDialog::ScoresDialog(Gtk::Window &parent)
   : Gtk::Dialog("Scores", parent, true), // modal dialog
     geometry_label("", Gtk::ALIGN_START), mode1_label("", Gtk::ALIGN_START),
+    buttons_box(Gtk::ORIENTATION_HORIZONTAL),
+    filters_box(Gtk::ORIENTATION_VERTICAL),
+    reflect_box(Gtk::ORIENTATION_HORIZONTAL),
+    mode2_box(Gtk::ORIENTATION_HORIZONTAL),
+    size_box(Gtk::ORIENTATION_HORIZONTAL),
+    empty_box(Gtk::ORIENTATION_HORIZONTAL),
     active_game(-1), active_row(-1)
 {
   get_vbox()->set_spacing(6);
